# Makefile for Persistence of Vision Raytracer 3.0
# For use with DJ's GCC under MS-Dos
#

#CFLAGS=-O3 -m486 -funroll-loops
#MORECFLAGS=-Wall -Wtraditional -Wconversion -Wcast-align -Wpointer-arith -Wstrict-prototypes -Wmissing-prototypes

CFLAGS=-m486 -funroll-loops -ffloat-store 
#MORECFLAGS=

#
# Uncomment for debugging (no optimization)
# Comment the strip command below to be able to debug
#

#CFLAGS	=-g
#MORECFLAGS=-Wall -Wtraditional -Wconversion -Wcast-align -Wpointer-arith -Wstrict-prototypes -Wmissing-prototypes

#directory macros
S=../../
M=../
P=../../libpng/
Z=../../zlib/
C=gcc -I$(S) -I$(M) -I$(P) -I$(Z) $(CFLAGS) $(MORECFLAGS) -c


# POV-Ray objects

POVOBJS = atmosph.o bbox.o bezier.o blob.o boxes.o bsphere.o \
  camera.o chi2.o colour.o cones.o console.o csg.o \
  discs.o express.o fractal.o gif.o \
  gifdecod.o halos.o hcmplx.o hfield.o iff.o image.o \
  quatern.o lathe.o lbuffer.o lighting.o matrices.o \
  mem.o mesh.o msdostxt.o msdosvid.o vesavbe.o normal.o \
  objects.o octree.o optin.o optout.o parse.o \
  parstxtr.o pattern.o pgm.o pigment.o planes.o png_pov.o \
  point.o poly.o polygon.o polysolv.o povray.o ppm.o \
  prism.o quadrics.o radiosit.o ray.o render.o rad_data.o \
  sor.o spheres.o super.o targa.o texture.o \
  tokenize.o torus.o triangle.o truetype.o txttest.o \
  userio.o vbuffer.o vlbuffer.o warps.o

#
# DJGCC Linkage...
#

povray.exe : $(POVOBJS)
	gcc -o povray @msdosgcc.lnk 
	strip povray
	coff2exe povray
	del povray.

#
# Specific module/header dependencies for POV-Ray:
#

atmosph.o : $(S)atmosph.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(S)colour.h \
  $(M)config.h $(S)frame.h $(S)lighting.h $(S)objects.h $(S)pattern.h \
  $(S)pigment.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h \
  $(S)texture.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)atmosph.c 

bbox.o : $(S)bbox.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)bbox.c 

bezier.o : $(S)bezier.c $(S)atmosph.h $(S)bbox.h $(S)bezier.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)bezier.c 

blob.o : $(S)blob.c $(S)atmosph.h $(S)bbox.h $(S)blob.h $(S)bsphere.h \
  $(S)camera.h $(M)config.h $(S)frame.h $(S)lighting.h $(S)matrices.h \
  $(S)objects.h $(S)pattern.h $(S)point.h $(S)polysolv.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)texture.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)blob.c 

boxes.o : $(S)boxes.c $(S)atmosph.h $(S)bbox.h $(S)boxes.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)boxes.c 

bsphere.o : $(S)bsphere.c $(S)bsphere.h $(M)config.h $(S)frame.h \
  $(S)povproto.h $(S)vector.h 
	$(C) $(S)bsphere.c 

camera.o : $(S)camera.c $(S)camera.h $(M)config.h $(S)frame.h $(S)matrices.h \
  $(S)normal.h $(S)povproto.h $(S)vector.h 
	$(C) $(S)camera.c 

chi2.o : $(S)chi2.c $(S)chi2.h $(M)config.h $(S)frame.h $(S)povproto.h 
	$(C) $(S)chi2.c 

colour.o : $(S)colour.c $(S)colour.h $(M)config.h $(S)frame.h $(S)normal.h \
  $(S)pattern.h $(S)pigment.h $(S)povproto.h $(S)texture.h $(S)vector.h \
  $(S)warps.h 
	$(C) $(S)colour.c 

cones.o : $(S)cones.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(S)cones.h \
  $(M)config.h $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)cones.c 

console.o : $(M)console.c $(M)console.h $(M)debug.h $(M)msdosall.h $(M)pmode.h 
	$(C) $(M)console.c 

csg.o : $(S)csg.c $(S)atmosph.h $(S)bbox.h $(S)boxes.h $(S)camera.h \
  $(M)config.h $(S)csg.h $(S)frame.h $(S)hfield.h $(S)matrices.h \
  $(S)objects.h $(S)planes.h $(S)point.h $(S)povproto.h $(S)povray.h \
  $(S)quadrics.h $(S)render.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)csg.c 

discs.o : $(S)discs.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)discs.h $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)discs.c 

express.o : $(S)express.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(S)colour.h \
  $(M)config.h $(S)express.h $(S)frame.h $(S)matrices.h $(S)normal.h \
  $(S)parse.h $(S)parstxtr.h $(S)pattern.h $(S)pigment.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)texture.h $(S)tokenize.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)express.c 

fractal.o : $(S)fractal.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)fractal.h $(S)frame.h $(S)hcmplx.h $(S)quatern.h $(S)matrices.h \
  $(S)objects.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h \
  $(S)spheres.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)fractal.c 

gif.o : $(S)gif.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)gif.h $(S)gifdecod.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)gif.c 

gifdecod.o : $(S)gifdecod.c $(M)config.h $(S)frame.h $(S)gif.h $(S)gifdecod.h \
  $(S)povproto.h 
	$(C) $(S)gifdecod.c 

halos.o : $(S)halos.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(S)colour.h \
  $(M)config.h $(S)frame.h $(S)halos.h $(S)lighting.h $(S)matrices.h \
  $(S)objects.h $(S)pattern.h $(S)point.h $(S)povproto.h $(S)povray.h \
  $(S)render.h $(S)texture.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)halos.c 

hcmplx.o : $(S)hcmplx.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)fractal.h $(S)frame.h $(S)hcmplx.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)spheres.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)hcmplx.c 

hfield.o : $(S)hfield.c $(S)atmosph.h $(S)bbox.h $(S)boxes.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)hfield.h $(S)matrices.h $(S)objects.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)hfield.c 

iff.o : $(S)iff.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)iff.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)iff.c 

image.o : $(S)image.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)image.h $(S)matrices.h $(S)pattern.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)texture.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)image.c 

quatern.o : $(S)quatern.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)fractal.h $(S)frame.h $(S)quatern.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)spheres.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)quatern.c 

lathe.o : $(S)lathe.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)lathe.h $(S)matrices.h $(S)objects.h $(S)point.h \
  $(S)polysolv.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)torus.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)lathe.c 

lbuffer.o : $(S)lbuffer.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)lbuffer.h $(S)objects.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)triangle.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)lbuffer.c 

lighting.o : $(S)lighting.c $(S)atmosph.h $(S)bbox.h $(S)blob.h \
  $(S)bsphere.h $(S)camera.h $(S)colour.h $(M)config.h $(S)frame.h \
  $(S)halos.h $(S)image.h $(S)lbuffer.h $(S)lighting.h $(S)mesh.h \
  $(S)normal.h $(S)objects.h $(S)octree.h $(S)pattern.h $(S)pigment.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)radiosit.h $(S)ray.h \
  $(S)render.h $(S)texture.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)lighting.c 

matrices.o : $(S)matrices.c $(M)config.h $(S)frame.h $(S)matrices.h \
  $(S)povproto.h $(S)vector.h 
	$(C) $(S)matrices.c 

mem.o : $(S)mem.c $(M)config.h $(S)frame.h $(S)mem.h $(S)parse.h \
  $(S)povproto.h 
	$(C) $(S)mem.c 

mesh.o : $(S)mesh.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)mesh.h $(S)objects.h $(S)pattern.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)texture.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)mesh.c 

msdostxt.o : $(M)msdostxt.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(M)console.h $(M)debug.h $(S)frame.h $(M)msdosall.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(M)msdostxt.c 

msdosvid.o : $(M)msdosvid.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(M)console.h $(M)debug.h $(S)frame.h $(M)msdosall.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)vlbuffer.h \
  $(S)warps.h $(M)vesavbe.h
	$(C) $(M)msdosvid.c 

vesavbe.o : $(M)vesavbe.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(M)console.h $(M)debug.h $(S)frame.h $(M)msdosall.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)vlbuffer.h \
  $(S)warps.h $(M)vesavbe.h
	$(C) $(M)vesavbe.c 

normal.o : $(S)normal.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)image.h $(S)matrices.h $(S)normal.h $(S)pattern.h \
  $(S)pigment.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h \
  $(S)texture.h $(S)txttest.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)normal.c 

objects.o : $(S)objects.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)objects.h $(S)pattern.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)texture.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)objects.c 

octree.o : $(S)octree.c $(M)config.h $(S)frame.h $(S)octree.h $(S)povproto.h \
  $(S)radiosit.h $(S)vector.h 
	$(C) $(S)octree.c 

optin.o : $(S)optin.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)lighting.h $(S)mem.h $(S)octree.h $(S)optin.h $(S)optout.h \
  $(S)parse.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)ppm.h \
  $(S)radiosit.h $(S)render.h $(S)targa.h $(S)tokenize.h $(S)userio.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)optin.c 

optout.o : $(S)optout.c $(S)atmosph.h $(S)bbox.h $(S)bezier.h $(S)blob.h \
  $(S)boxes.h $(S)bsphere.h $(S)camera.h $(S)cones.h $(M)config.h $(S)csg.h \
  $(S)discs.h $(S)fractal.h $(S)frame.h $(S)hfield.h $(S)lathe.h \
  $(S)lbuffer.h $(S)lighting.h $(S)mesh.h $(S)objects.h $(S)octree.h \
  $(S)optin.h $(S)optout.h $(S)parse.h $(S)pattern.h $(S)pgm.h $(S)planes.h \
  $(S)point.h $(S)poly.h $(S)polygon.h $(S)polysolv.h $(S)povproto.h \
  $(S)povray.h $(S)ppm.h $(S)prism.h $(S)quadrics.h $(S)radiosit.h \
  $(S)render.h $(S)sor.h $(S)spheres.h $(S)super.h $(S)targa.h $(S)texture.h \
  $(S)torus.h $(S)triangle.h $(S)truetype.h $(S)userio.h $(S)vbuffer.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)optout.c 

parse.o : $(S)parse.c $(S)atmosph.h $(S)bbox.h $(S)bezier.h $(S)blob.h \
  $(S)boxes.h $(S)bsphere.h $(S)camera.h $(S)colour.h $(S)cones.h \
  $(M)config.h $(S)csg.h $(S)discs.h $(S)express.h $(S)fractal.h $(S)frame.h \
  $(S)gif.h $(S)halos.h $(S)hfield.h $(S)iff.h $(S)image.h $(S)lathe.h \
  $(S)matrices.h $(S)mesh.h $(S)normal.h $(S)objects.h $(S)octree.h \
  $(S)parse.h $(S)parstxtr.h $(S)pattern.h $(S)pgm.h $(S)pigment.h \
  $(S)planes.h $(S)point.h $(S)poly.h $(S)polygon.h $(S)polysolv.h \
  $(S)povproto.h $(S)povray.h $(S)ppm.h $(S)prism.h $(S)quadrics.h \
  $(S)radiosit.h $(S)render.h $(S)sor.h $(S)spheres.h $(S)super.h \
  $(S)targa.h $(S)texture.h $(S)tokenize.h $(S)torus.h $(S)triangle.h \
  $(S)truetype.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)parse.c 

parstxtr.o : $(S)parstxtr.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(S)colour.h $(M)config.h $(S)express.h $(S)frame.h $(S)gif.h $(S)halos.h \
  $(S)iff.h $(S)image.h $(S)matrices.h $(S)normal.h $(S)parse.h \
  $(S)parstxtr.h $(S)pattern.h $(S)pgm.h $(S)pigment.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)ppm.h $(S)render.h $(S)targa.h \
  $(S)texture.h $(S)tokenize.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)parstxtr.c 

pattern.o : $(S)pattern.c $(S)colour.h $(M)config.h $(S)frame.h $(S)image.h \
  $(S)matrices.h $(S)pattern.h $(S)povproto.h $(S)texture.h $(S)txttest.h \
  $(S)vector.h $(S)warps.h 
	$(C) $(S)pattern.c 

pgm.o : $(S)pgm.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)pgm.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)ppm.h \
  $(S)render.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)pgm.c 

pigment.o : $(S)pigment.c $(S)colour.h $(M)config.h $(S)frame.h $(S)image.h \
  $(S)matrices.h $(S)pattern.h $(S)pigment.h $(S)povproto.h $(S)texture.h \
  $(S)txttest.h $(S)vector.h $(S)warps.h 
	$(C) $(S)pigment.c 

planes.o : $(S)planes.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)planes.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)planes.c 

png_pov.o : $(S)png_pov.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)optout.h $(P)png.h $(S)png_pov.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)png_pov.c 

point.o : $(S)point.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)point.c 

poly.o : $(S)poly.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)poly.h \
  $(S)polysolv.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)poly.c 

polygon.o : $(S)polygon.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)polygon.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)polygon.c 

polysolv.o : $(S)polysolv.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)point.h $(S)polysolv.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)polysolv.c 

povray.o : $(S)povray.c $(S)atmosph.h $(S)bbox.h $(S)bezier.h $(S)blob.h \
  $(S)boxes.h $(S)bsphere.h $(S)camera.h $(S)cones.h $(M)config.h $(S)csg.h \
  $(S)discs.h $(S)fractal.h $(S)frame.h $(S)hfield.h $(S)lathe.h \
  $(S)lbuffer.h $(S)lighting.h $(S)mem.h $(S)mesh.h $(S)objects.h \
  $(S)octree.h $(S)optin.h $(S)optout.h $(S)parse.h $(S)pattern.h $(S)pgm.h \
  $(S)planes.h $(S)png_pov.h $(S)point.h $(S)poly.h $(S)polygon.h \
  $(S)polysolv.h $(S)povproto.h $(S)povray.h $(S)ppm.h $(S)prism.h \
  $(S)quadrics.h $(S)radiosit.h $(S)render.h $(S)sor.h $(S)spheres.h \
  $(S)super.h $(S)targa.h $(S)texture.h $(S)tokenize.h $(S)torus.h \
  $(S)triangle.h $(S)truetype.h $(S)userio.h $(S)vbuffer.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)povray.c 

ppm.o : $(S)ppm.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)pgm.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)ppm.h \
  $(S)render.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)ppm.c 

prism.o : $(S)prism.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)polysolv.h \
  $(S)povproto.h $(S)povray.h $(S)prism.h $(S)render.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)prism.c 

quadrics.o : $(S)quadrics.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)matrices.h $(S)objects.h $(S)planes.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)quadrics.h $(S)render.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)quadrics.c 

radiosit.o : $(S)radiosit.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)octree.h $(S)optin.h $(S)pattern.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)radiosit.h $(S)render.h $(S)texture.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)radiosit.c 

rad_data.o : $(S)rad_data.c $(M)config.h $(S)frame.h $(S)octree.h \
  $(S)povproto.h $(S)radiosit.h 
	$(C) $(S)rad_data.c 

ray.o : $(S)ray.c $(M)config.h $(S)frame.h $(S)povproto.h $(S)ray.h \
  $(S)vector.h 
	$(C) $(S)ray.c 

render.o : $(S)render.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(S)chi2.h \
  $(S)colour.h $(M)config.h $(S)frame.h $(S)lighting.h $(S)normal.h \
  $(S)objects.h $(S)octree.h $(S)optout.h $(S)pattern.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)radiosit.h $(S)ray.h $(S)render.h \
  $(S)targa.h $(S)texture.h $(S)userio.h $(S)vbuffer.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)render.c 

sor.o : $(S)sor.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)polysolv.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)sor.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)sor.c 

spheres.o : $(S)spheres.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)spheres.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)spheres.c 

super.o : $(S)super.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)povproto.h \
  $(S)povray.h $(S)render.h $(S)super.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)super.c 

targa.o : $(S)targa.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h \
  $(S)targa.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)targa.c 

texture.o : $(S)texture.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)halos.h $(S)image.h $(S)matrices.h $(S)normal.h \
  $(S)pattern.h $(S)pigment.h $(S)point.h $(S)povproto.h $(S)povray.h \
  $(S)render.h $(S)texture.h $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)texture.c 

tokenize.o : $(S)tokenize.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(S)express.h $(S)frame.h $(S)parse.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)tokenize.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)tokenize.c 

torus.o : $(S)torus.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h $(S)polysolv.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)torus.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)torus.c 

triangle.o : $(S)triangle.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)matrices.h $(S)objects.h $(S)point.h \
  $(S)povproto.h $(S)povray.h $(S)render.h $(S)triangle.h $(S)vector.h \
  $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)triangle.c 

truetype.o : $(S)truetype.c $(S)atmosph.h $(S)bbox.h $(S)camera.h \
  $(M)config.h $(S)csg.h $(S)frame.h $(S)matrices.h $(S)objects.h \
  $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h $(S)truetype.h \
  $(S)vector.h $(S)vlbuffer.h $(S)warps.h 
	$(C) $(S)truetype.c 

txttest.o : $(S)txttest.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)pattern.h $(S)point.h $(S)povproto.h $(S)povray.h \
  $(S)render.h $(S)texture.h $(S)txttest.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)txttest.c 

userio.o : $(S)userio.c $(S)atmosph.h $(S)bbox.h $(S)camera.h $(M)config.h \
  $(S)frame.h $(S)parse.h $(S)point.h $(S)povproto.h $(S)povray.h \
  $(S)render.h $(S)tokenize.h $(S)userio.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)userio.c 

vbuffer.o : $(S)vbuffer.c $(S)atmosph.h $(S)bbox.h $(S)boxes.h $(S)camera.h \
  $(M)config.h $(S)frame.h $(S)hfield.h $(S)lighting.h $(S)matrices.h \
  $(S)objects.h $(S)point.h $(S)povproto.h $(S)povray.h $(S)render.h \
  $(S)triangle.h $(S)userio.h $(S)vbuffer.h $(S)vector.h $(S)vlbuffer.h \
  $(S)warps.h 
	$(C) $(S)vbuffer.c 

vlbuffer.o : $(S)vlbuffer.c $(S)bbox.h $(M)config.h $(S)frame.h \
  $(S)povproto.h $(S)vector.h $(S)vlbuffer.h 
	$(C) $(S)vlbuffer.c 

warps.o : $(S)warps.c $(M)config.h $(S)frame.h $(S)matrices.h $(S)pattern.h \
  $(S)povproto.h $(S)texture.h $(S)vector.h $(S)warps.h 
	$(C) $(S)warps.c 
